{% load i18n %}
{% load static from staticfiles %}
<div id="header-logo">
    <a class="icon-logo" href="/"><span>django CMS</span></a>
</div>
<h1>{{ site_header|default:_('Django Administration') }}</h1>
<ul id="site-name" class="toolbar-item toolbar-item-navigation">
    <li>
        <a class="menu-item" href="">{{ site_header|default:_('Django Administration') }}</a>
        <ul class="submenu">
            {% if user.has_usable_password %}
                <li>
                    <a href="{% url 'admin:password_change' %}">{% trans 'Change password' %}</a>
                </li>
                <li class="toolbar-item-navigation-break">-----</li>
            {% endif %}
            <li>
                <a href="{% url 'admin:logout' %}">
                    <span>{% trans 'Log out' %} {% firstof user.get_short_name user.get_username %}</span>
                </a>
            </li>
        </ul>
    </li>
</ul>
<div id="header-btn">
    <a href="/" class="icon-arrow-right btn js-header-link">
        {% trans 'Open' %} {{ request.site.name|default:_('my site') }}
    </a>
</div>

<script src="{% static 'js/drag-touch-support.js' %}"></script>
<script src="{% static 'js/base-admin.js' %}"></script>
<script src="{% static 'js/jquery.ui.touch-punch.min.js' %}"></script>
